==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/language/1/barnraiser_01/arrays/arr_rsp.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// STATUS IDS -----------------------------------------------------
$lang['rsp']['status'][3] = 								"live";
$lang['rsp']['status'][2] = 								"hold";
$lang['rsp']['status'][1] = 								"pending";

$lang['rsp']['item_type'][1] = 								"blog";
$lang['rsp']['item_type'][2] = 								"wiki";
$lang['rsp']['item_type'][3] = 								"file";
$lang['rsp']['item_type'][4] = 								"schedule";
$lang['rsp']['item_type'][5] = 								"discussion";
$lang['rsp']['item_type'][6] = 								"poll";
$lang['rsp']['item_type'][7] = 								"channel";
$lang['rsp']['item_type'][8] = 								"network";
$lang['rsp']['item_type'][9] = 								"group";

$lang['rsp']['rsp_level'][64] = 							"public";
$lang['rsp']['rsp_level'][32] = 							"community";
$lang['rsp']['rsp_level'][16] = 							"degree";
$lang['rsp']['rsp_level'][4] = 								"group home page";

?>

==> igloo_0_1_7.tar.tgz: igloo_0_1_7/igloo/language/1/barnraiser_01/arrays/arr_rsp.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// STATUS IDS -----------------------------------------------------
$lang['rsp']['status'][3] = 								"live";
$lang['rsp']['status'][2] = 								"hold";
$lang['rsp']['status'][1] = 								"pending";

$lang['rsp']['item_type'][1] = 								"blog";
$lang['rsp']['item_type'][2] = 								"wiki";
$lang['rsp']['item_type'][3] = 								"file";
$lang['rsp']['item_type'][4] = 								"schedule";
$lang['rsp']['item_type'][5] = 								"discussion";
$lang['rsp']['item_type'][6] = 								"poll";
$lang['rsp']['item_type'][7] = 								"channel";
$lang['rsp']['item_type'][8] = 								"network";

$lang['rsp']['rsp_level'][32] = 							"public";
$lang['rsp']['rsp_level'][16] = 							"group";

// network only
$lang['rsp']['rsp_level_degree'][1] = 						"1st degree network";

?>
